@@ -2,6 +2,7 @@
 PASSWORD_RESET_TIMEOUT_DAYS setting replaced with PASSWORD_RESET_TIMEOUT:
 https://docs.djangoproject.com/en/3.1/releases/3.1/#django-contrib-auth
 """
+
 from __future__ import annotations
 
 import ast
@@ -16,12 +17,13 @@ from django_upgrade.data import Fixer
 from django_upgrade.data import State
 from django_upgrade.data import TokenFunc
 from django_upgrade.tokens import CODE
-from django_upgrade.tokens import find
 from django_upgrade.tokens import OP
+from django_upgrade.tokens import find
 
 fixer = Fixer(
     __name__,
     min_version=(3, 1),
+    condition=lambda state: state.looks_like_settings_file,
 )
 
 OLD_NAME = "PASSWORD_RESET_TIMEOUT_DAYS"
@@ -35,8 +37,7 @@ def visit_Assign(
     parents: list[ast.AST],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        state.looks_like_settings_file
-        and len(node.targets) == 1
+        len(node.targets) == 1
         and isinstance(node.targets[0], ast.Name)
         and node.targets[0].id == OLD_NAME
     ):
